@@ -197,9 +197,13 @@ class Column:
         _is_foreign_key:bool = None
         '''True if this column has a foreign key constraint to another table.'''
         foreign_table_name:str = None
+        '''The name of the foreign_table that this column references'''
         foreign_table_schema:str = None
+        '''The name of the foreign table's schema that this column references'''
         foreign_column_name:str = None
+        '''The name of the foreign column that this column references'''
         foreign_key_constraint_name:str = None
+        '''The name of the foreign key constraint'''
 
         py_data_type:str = None
         '''The SQL data type converted to its python equivalent'''
