@@ -1080,8 +1080,39 @@ class MySQLDatabase:
         if len(output) == 0:
             output = default
         return output
+    
+    def get_all_tables(self)->Iterable[_db_table_type]:
+        '''
+            Retrieve all tables from this database.
+            
+            ----------
 
 
+            Return {list}
+            ----------------------
+            A list of table instances.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 12-15-2022 13:27:01
+            `memberOf`: MySQLDatabase
+            `version`: 1.0
+            `method_name`: get_all_tables
+            * @xxx [12-15-2022 13:30:59]: documentation for get_all_tables
+        '''
+        sql = f"""select TABLE_NAME
+            from INFORMATION_SCHEMA.TABLES
+            where table_type = 'BASE TABLE'
+                    and table_schema = '{self.database}'"""
+        result = self.run_select(sql)
+        output = []
+        for table in result:
+            table = _obj.keys_to_snake_case(table)
+            table = self.get_table(table['table_name'])
+            output.append(table)
+        return output
+
     # def get_table_meta_data(self):
 
 
