@@ -1259,7 +1259,7 @@ class TableManager:
 
         if self.settings['raw_statement'] is not None:
             sql = self.settings['raw_statement']
-            # sql = f"--====================================================================== CREATE\n\n\n{sql}"
+            sql = f"--====================================================================== CREATE\n\n\n{sql}"
             sql = gen_drop_table(self.name,self.schema,sql)
             sql = prepend_header(None,sql)
             self.data['content_hash'] = csu.gen.to_hash(self.settings['raw_statement'])
